@@ -3,6 +3,9 @@ import UserNotifications
 
 
 class TestUNError(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(UserNotifications.UNErrorCode)
+
     def test_constants(self):
         self.assertEqual(UserNotifications.UNErrorCodeNotificationsNotAllowed, 1)
         self.assertEqual(UserNotifications.UNErrorCodeAttachmentInvalidURL, 100)
@@ -17,3 +20,8 @@ class TestUNError(TestCase):
         self.assertEqual(
             UserNotifications.UNErrorCodeNotificationInvalidNoContent, 1401
         )
+        self.assertEqual(
+            UserNotifications.UNErrorCodeContentProvidingObjectNotAllowed, 1500
+        )
+        self.assertEqual(UserNotifications.UNErrorCodeContentProvidingInvalid, 1501)
+        self.assertEqual(UserNotifications.UNErrorCodeBadgeInputInvalid, 1600)
